@@ -775,7 +775,10 @@ gpe <- function(
   modmat_formula <- lapply(formulas, paste0, collapse = " + ")
   modmat_formula <- paste0(unlist(modmat_formula), collapse = " + ")
   modmat_formula <- stats::formula(paste("~", modmat_formula))
+  
   x <- model.matrix(modmat_formula, data = data)
+  #x <- Matrix::sparse.model.matrix(modmat_formula, data = data) # may save computation time but currently breaks stuff (at leas in pre)
+  
   Terms <- terms(modmat_formula, data = data)
   
   ##################################################
@@ -790,7 +793,7 @@ gpe <- function(
   ####################
   
   result <- list(
-    glmnet.fit = glmnet.fit, call = match.call, 
+    glmnet.fit = glmnet.fit, call = match.call(), 
     family = family, base_learners = base_learners, 
     modmat_formula = modmat_formula, terms = Terms)
   
